@@ -5,6 +5,7 @@
 #' in a genind object.
 #'
 #' @param x genind object (from package adegenet)
+#' @param linearized logical, if TRUE will turned linearized G'st (1/()1-G'st))
 #' @export
 #' @examples
 #' 
@@ -12,15 +13,17 @@
 #' pairwise_Gst_Hedrick(nancycats[1:26,])
 #' @references
 #'  Hedrick, PW. (2005), A Standardized Genetic Differentiation Measure. Evolution 59: 1633-1638. 
+#' @references
+#'  Merimans, PG and Hedrick PW. (2010), Assessing population structure: FST and related measures. Molecular Ecology Resources 11: 5-18
 #' @family pairwise
 #' @family Hedrick
 
-pairwise_Gst_Hedrick<- function(x) {
+pairwise_Gst_Hedrick<- function(x, linearized=FALSE) {
   pops <- seppop(x)
   n.pops <- length(pops)
   #all combinations 
   allP <- combn(1:n.pops, 2)
-  # calculate tfh statistic
+  # calculate the statistic
   pair <- function(index.a,index.b){
     a <- pops[[index.a]]
     b <- pops[[index.b]]
@@ -29,5 +32,8 @@ pairwise_Gst_Hedrick<- function(x) {
     }
   res <- sapply(1:dim(allP)[2], function(i) pair(allP[,i][1], allP[,i][2]))
   attributes(res) <- attributes(dist(1:n.pops))
-  return(as.matrix(res))
+  if(linearized){
+   return(res/(1-res))
+  }
+  return(res)
 }
